RadarrCommandHandler_Exclusions class

Facilitates, encapsulates, and manages individual calls related to exclusions within Radarr.

RadarrCommandHandler_Exclusions internally handles routing the HTTP client to the API calls.

Constructors

RadarrCommandHandler_Exclusions(Dio _client)
Create a command handler using an initialized Dio client.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get({required int exclusionId}) → Future<RadarrExclusion>
Handler for exclusions/{id}.
getAll() → Future<List<RadarrExclusion>>
Handler for exclusions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited