RadarrCommandHandler_History class

Facilitates, encapsulates, and manages individual calls related to a movie's extra files within Radarr.

RadarrCommandHandler_History internally handles routing the HTTP client to the API calls.

Constructors

RadarrCommandHandler_History(Dio _client)
Create a command handler using an initialized Dio client.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get({int? page, int? pageSize, RadarrSortDirection? sortDirection, RadarrHistorySortKey? sortKey}) → Future<RadarrHistory>
Handler for history.
getForMovie({required int movieId}) → Future<List<RadarrHistoryRecord>>
Handler for history/movie/{id}.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited