RadarrCommandHandler_ImportList class

Facilitates, encapsulates, and manages individual calls related to import lists within Radarr.

RadarrCommandHandler_ImportList internally handles routing the HTTP client to the API calls.

Constructors

RadarrCommandHandler_ImportList(Dio _client)
Create a command handler using an initialized Dio client.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get({required int listId}) → Future<RadarrImportList>
Handler for importlist/{id}.
getAll() → Future<List<RadarrImportList>>
Handler for impostlist.
getMovies({bool? includeRecommendations}) → Future<List<RadarrMovie>>
Handler for impostlist/movie.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited