RadarrEventType enum

Inheritance
Available extensions

Values

GRABBED → const RadarrEventType
DOWNLOAD_FAILED → const RadarrEventType
DOWNLOAD_FOLDER_IMPORTED → const RadarrEventType
DOWNLOAD_IGNORED → const RadarrEventType
MOVIE_FILE_DELETED → const RadarrEventType
MOVIE_FILE_RENAMED → const RadarrEventType
MOVIE_FOLDER_IMPORTED → const RadarrEventType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
readable → String?

Available on RadarrEventType, provided by the RadarrEventTypeExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?

Available on RadarrEventType, provided by the RadarrEventTypeExtension extension

no setter

Methods

from(String? type) → RadarrEventType?

Available on RadarrEventType, provided by the RadarrEventTypeExtension extension

Given a String, will return the correct RadarrEventType object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RadarrEventType>
A constant List of the values in this enum, in order of their declaration.