RadarrImportMode enum

Inheritance
Available extensions

Values

COPY → const RadarrImportMode
MOVE → const RadarrImportMode

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String

Available on RadarrImportMode, provided by the RadarrImportModeExtension extension

no setter

Methods

from(String? type) → RadarrImportMode?

Available on RadarrImportMode, provided by the RadarrImportModeExtension extension

Given a String, will return the correct RadarrImportMode object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RadarrImportMode>
A constant List of the values in this enum, in order of their declaration.