RadarrTrackedDownloadState enum

Inheritance
Available extensions

Values

DOWNLOADING → const RadarrTrackedDownloadState
FAILED_PENDING → const RadarrTrackedDownloadState
IMPORT_PENDING → const RadarrTrackedDownloadState
IMPORTING → const RadarrTrackedDownloadState

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
key → String

Available on RadarrTrackedDownloadState, provided by the RadarrTrackedDownloadStateExtension extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

from(String? key) → RadarrTrackedDownloadState?

Available on RadarrTrackedDownloadState, provided by the RadarrTrackedDownloadStateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RadarrTrackedDownloadState>
A constant List of the values in this enum, in order of their declaration.