RadarrTrackedDownloadStatus enum

Inheritance
Available extensions

Values

OK → const RadarrTrackedDownloadStatus
ERROR → const RadarrTrackedDownloadStatus
WARNING → const RadarrTrackedDownloadStatus

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
key → String

Available on RadarrTrackedDownloadStatus, provided by the RadarrTrackedDownloadStatusExtension extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

from(String? key) → RadarrTrackedDownloadStatus?

Available on RadarrTrackedDownloadStatus, provided by the RadarrTrackedDownloadStatusExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RadarrTrackedDownloadStatus>
A constant List of the values in this enum, in order of their declaration.